pub async fn confirm_gateway_reinitialize(state_dir: &Path) -> Result<bool>
Asks whether existing gateway state may be permanently replaced.
Returns an error if validation or an operation required by this function fails.