pub async fn run_cloudflare_setup() -> Result<Option<CloudflareInit>>Expand description
Collects an existing tunnel hostname and connector token without echoing the token.
Errors
Returns an error if validation or an operation required to complete the request fails.